@@ -14,7 +14,7 @@ ZPA_BASE_URLS = {
 
 DEV_AUTH_URL = "https://authn1.dev.zpath.net/authn/v1/oauth/token"
 
-RETRYABLE_STATUS_CODES = {429, 500, 502, 503, 504}
+RETRYABLE_STATUS_CODES = {409, 429, 500, 502, 503, 504}
 MAX_RETRIES = 5
 BACKOFF_FACTOR = 1
 BACKOFF_BASE_DURATION = 2
